@@ -49,9 +49,9 @@ EV - perl interface to libev, a high performance full-featured event loop
    };
    
    # MAINLOOP
-   EV::loop;           # loop until EV::unloop is called or all watchers stop
-   EV::loop EV::LOOP_ONESHOT;  # block until at least one event could be handled
-   EV::loop EV::LOOP_NONBLOCK; # try to handle same events, but do not block
+   EV::run;                # loop until EV::unloop is called or all watchers stop
+   EV::run EV::RUN_ONCE;   # block until at least one event could be handled
+   EV::run EV::RUN_NOWAIT; # try to handle same events, but do not block
 
 =head1 BEFORE YOU START USING THIS MODULE
 
@@ -121,8 +121,9 @@ package EV;
 use common::sense;
 
 BEGIN {
-   our $VERSION = '4.02';
+   our $VERSION = '4.16';
    use XSLoader;
+   local $^W = 0; # avoid spurious warning
    XSLoader::load "EV", $VERSION;
 }
 
@@ -188,7 +189,7 @@ the event loop. An alternative is to use C<EV::FLAG_FORKCHECK> which calls
 this function automatically, at some performance loss (refer to the libev
 documentation).
 
-=item $loop->loop_verify
+=item $loop->verify
 
 Calls C<ev_verify> to make internal consistency checks (for debugging
 libev) and abort the program if any data structures were found to be
@@ -292,32 +293,39 @@ loop time (see C<now_update>).
 Returns an integer describing the backend used by libev (EV::BACKEND_SELECT
 or EV::BACKEND_EPOLL).
 
-=item EV::loop [$flags]
+=item $active = EV::run [$flags]
 
-=item $loop->loop ([$flags])
+=item $active = $loop->run ([$flags])
 
 Begin checking for events and calling callbacks. It returns when a
-callback calls EV::unloop.
+callback calls EV::unloop or the flasg are nonzero (in which case the
+return value is true) or when there are no active watchers which reference
+the loop (keepalive is true), in which case the return value will be
+false. The returnv alue can generally be interpreted as "if true, there is
+more work left to do".
 
 The $flags argument can be one of the following:
 
-   0                  as above
-   EV::LOOP_ONESHOT   block at most once (wait, but do not loop)
-   EV::LOOP_NONBLOCK  do not block at all (fetch/handle events but do not wait)
+   0               as above
+   EV::RUN_ONCE    block at most once (wait, but do not loop)
+   EV::RUN_NOWAIT  do not block at all (fetch/handle events but do not wait)
 
-=item EV::unloop [$how]
+=item EV::break [$how]
 
-=item $loop->unloop ([$how])
+=item $loop->break ([$how])
 
-When called with no arguments or an argument of EV::UNLOOP_ONE, makes the
+When called with no arguments or an argument of EV::BREAK_ONE, makes the
 innermost call to EV::loop return.
 
-When called with an argument of EV::UNLOOP_ALL, all calls to EV::loop will return as
-fast as possible.
+When called with an argument of EV::BREAK_ALL, all calls to EV::loop will
+return as fast as possible.
 
-=item $count = EV::loop_count
+When called with an argument of EV::BREAK_CANCEL, any pending break will
+be cancelled.
 
-=item $count = $loop->loop_count
+=item $count = EV::iteration
+
+=item $count = $loop->iteration
 
 Return the number of times the event loop has polled for new
 events. Sometimes useful as a generation counter.
@@ -347,7 +355,7 @@ EV::once doesn't return anything: the watchers stay active till either
 of them triggers, then they will be stopped and freed, and the callback
 invoked.
 
-=item EV::feed_fd_event ($fd, $revents)
+=item EV::feed_fd_event $fd, $revents
 
 =item $loop->feed_fd_event ($fd, $revents)
 
@@ -355,10 +363,16 @@ Feed an event on a file descriptor into EV. EV will react to this call as
 if the readyness notifications specified by C<$revents> (a combination of
 C<EV::READ> and C<EV::WRITE>) happened on the file descriptor C<$fd>.
 
-=item EV::feed_signal_event ($signal)
+=item EV::feed_signal_event $signal
 
-Feed a signal event into EV. EV will react to this call as if the signal
-specified by C<$signal> had occured.
+Feed a signal event into the default loop. EV will react to this call as
+if the signal specified by C<$signal> had occured.
+
+=item EV::feed_signal $signal
+
+Feed a signal event into EV - unlike C<EV::feed_signal_event>, this works
+regardless of which loop has registered the signal, and is mainly useful
+fro custom signal implementations.
 
 =item EV::set_io_collect_interval $time
 
@@ -670,7 +684,7 @@ time:
    my $hourly = EV::periodic 0, 3600, 0, sub { print "once/hour\n" };
 
 That doesn't mean there will always be 3600 seconds in between triggers,
-but only that the the clalback will be called when the system time shows a
+but only that the the callback will be called when the system time shows a
 full hour (UTC).
 
 Another way to think about it (for the mathematically inclined) is that
@@ -1128,12 +1142,21 @@ Please see the libev documentation for further details.
 
 =item $w = EV::async_ns $callback
 
+=item $w = $loop->async ($callback)
+
+=item $w = $loop->async_ns ($callback)
+
 =item $w->send
 
 =item $bool = $w->async_pending
 
 =back
 
+=head3 CLEANUP WATCHERS - how to clean up when the event loop goes away
+
+Cleanup watchers are not supported on the Perl level, they can only be
+used via XS currently.
+
 
 =head1 PERL SIGNALS
 
